aboutsummaryrefslogtreecommitdiffstats
path: root/include/osmosdr/osmosdr_sink_c.h
diff options
context:
space:
mode:
authorDimitri Stolnikov <horiz0n@gmx.net>2013-05-29 22:34:40 +0200
committerDimitri Stolnikov <horiz0n@gmx.net>2013-05-29 22:34:40 +0200
commit3e6a24e5d9e81878ac57281e7a9d3b23d3dbc6e8 (patch)
tree0c019966642fb57a39bc0e4b618b7477c6d0c955 /include/osmosdr/osmosdr_sink_c.h
parent9912dcd1e6686f7111549e50333148fde630949a (diff)
convert to gnuradio 3.7 interface
Diffstat (limited to 'include/osmosdr/osmosdr_sink_c.h')
-rw-r--r--include/osmosdr/osmosdr_sink_c.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/osmosdr/osmosdr_sink_c.h b/include/osmosdr/osmosdr_sink_c.h
index d3911e1..fa03300 100644
--- a/include/osmosdr/osmosdr_sink_c.h
+++ b/include/osmosdr/osmosdr_sink_c.h
@@ -22,13 +22,13 @@
#include <osmosdr/osmosdr_api.h>
#include <osmosdr/osmosdr_ranges.h>
-#include <gnuradio/gr_hier_block2.h>
+#include <gnuradio/hier_block2.h>
class osmosdr_sink_c;
/*
* We use boost::shared_ptr's instead of raw pointers for all access
- * to gr_blocks (and many other data structures). The shared_ptr gets
+ * to gr::blocks (and many other data structures). The shared_ptr gets
* us transparent reference counting, which greatly simplifies storage
* management issues. This is especially helpful in our hybrid
* C++ / Python system.
@@ -52,9 +52,9 @@ OSMOSDR_API osmosdr_sink_c_sptr osmosdr_make_sink_c ( const std::string & args =
* \brief Takes a stream of complex samples.
* \ingroup block
*
* This uses the preferred technique: subclassing gr_hier_block2.
*/
-class OSMOSDR_API osmosdr_sink_c : virtual public gr_hier_block2
+class OSMOSDR_API osmosdr_sink_c : virtual public gr::hier_block2
{
public:
/*!
@@ -52,9 +52,9 @@ OSMOSDR_API osmosdr_sink_c_sptr osmosdr_make_sink_c ( const std::string & args =
* \ingroup block
*
- * This uses the preferred technique: subclassing gr_hier_block2.
+ * This uses the preferred technique: subclassing gr::hier_block2.
*/